| design_surv | R Documentation |
This function generates the design parameters of a clinical trial for survival outcome.
design_surv(m0, alpha, beta, k, hr0, hr1, ta, tf, kappa, eta, frac)
m0 |
numeric Median survival time of control group. |
alpha |
numeric Type I error. |
beta |
numeric Type II error. |
k |
numeric Number of treatment arms. |
hr0 |
numeric Hazard ratio of ineffective treatment group vs control. |
hr1 |
numeric Hazard ratio of effective treatment group vs control. |
ta |
numeric Accrual time. |
tf |
numeric Follow-up time. |
kappa |
numeric Shape parameter (kappa=1 for exponential distribution). |
eta |
numeric Rate of loss to follow-up. |
frac |
numeric Vector of fractions for information time at each look. |
List of cumulative number of events for each stage of combined treatment and control groups along with total number of subjects and maximum total number of events for the trial. It also provides efficacy and futility boundaries of the trial.
design_surv(m0 = 20,
hr0 = 1,
hr1 = 0.65,
ta = 20,
tf = 40,
alpha = 0.05,
beta = 0.1,
k = 3,
kappa = 1,
eta = 0,
frac = c(1 / 2, 1))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.